@@ -111,7 +111,7 @@ __PACKAGE__->mk_accessors(
   )
 );
 
-our $VERSION = '2.0.5'; ## no critic (RequireInterpolationOfMetachars)
+our $VERSION = '2.0.6'; ## no critic (RequireInterpolationOfMetachars)
 
 our @EXPORT_OK = qw(
   create_urlencoded_content
@@ -1473,13 +1473,13 @@ sub _create_stealth_logger {
 ########################################################################
   my ( $self, $name, $level ) = @_;
 
-  my $sub_name = sprintf '%s::%s', $name, $level;
-
-  return
-    if defined *{$sub_name};
+  my $sub_name = sprintf '%s::%s', $name, uc $level;
 
   no strict 'refs'; ## no critic ProhibitNoStrict
 
+  return
+    if defined *{$sub_name}{CODE};
+
   *{$sub_name} = sub {
     if ( $self->get_logger && $self->get_logger->can($level) ) {
       $self->get_logger->$level(@_);
@@ -1515,8 +1515,8 @@ sub _set_default_logger {
   }
   else {
     for my $level (qw(debug trace info warn error )) {
-      $self->_create_stealth_logger( $level, __PACKAGE__ );
-      $self->_create_stealth_logger( $level, ref $self );
+      $self->_create_stealth_logger( __PACKAGE__, $level );
+      $self->_create_stealth_logger( ref($self),  $level );
     }
   }
 
@@ -2740,7 +2740,7 @@ response.
 
 =head1 VERSION
 
-This documentation refers to version 2.0.5 of C<Amazon::API>.
+This documentation refers to version 2.0.6 of C<Amazon::API>.
 
 =head1 DIAGNOSTICS
 
